summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/assocpage.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialogs/assocpage.h')
-rw-r--r--umbrello/umbrello/dialogs/assocpage.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/umbrello/umbrello/dialogs/assocpage.h b/umbrello/umbrello/dialogs/assocpage.h
index 469dd35d..dbb0eec8 100644
--- a/umbrello/umbrello/dialogs/assocpage.h
+++ b/umbrello/umbrello/dialogs/assocpage.h
@@ -45,11 +45,11 @@ public:
/**
* Constructs an instance of AssocPage.
*
* @param tqparent The tqparent of the page
* @param v The view the UMLObject being represented.
* @param o The UMLObject being represented
*/
- AssocPage(TQWidget *tqparent, UMLView * v, UMLObject * o);
+ AssocPage(TQWidget *parent, UMLView * v, UMLObject * o);
/**
* Standard deconstructor.
@@ -45,11 +45,11 @@ public:
* Constructs an instance of AssocPage.
*
- * @param tqparent The tqparent of the page
+ * @param parent The parent of the page
* @param v The view the UMLObject being represented.
* @param o The UMLObject being represented